Becca is a general learning program for use in any robot or embodied system. When using Becca, a robot learns to do whatever it is rewarded to do, and continues learning throughout its lifetime.

###How do I try Becca out?

Make sure you have a current version of Anaconda, and version 0.27 or higher of numba.
    
    conda update conda
    conda update anaconda
    conda update numba
    
Pull down the code from Pypi.

    pip install --pre becca
    pip install --pre becca_test
    
Run it on your local machine.
    
    python
    >>>import becca_test
    >>>becca_test.test.suite()

###What can Becca do?

Some [videos](http://youtu.be/4kPoU8eZvio?list=PLF861CC4C40439EEB) show Becca in action. 

###How does Becca work?

I owe you an update, but here's the 
[how it works](https://github.com/brohrer/becca-docs/blob/master/how_it_works.pdf?raw=true) 
document from a previous version. Some of the principles are the same. 

###How do I use Becca with my own robot? 

The [wiki](https://github.com/brohrer/becca/wiki) has tutorials on how to use Becca in your application.

[![Join the chat at https://gitter.im/brohrer/becca](https://badges.gitter.im/brohrer/becca.svg)](https://gitter.im/brohrer/becca?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge) provides a forum for users to share questions, solutions, and experiences. 

<a href="url"><img src="https://github.com/brohrer/becca-docs/raw/master/figs/logo_plate.png" 
align="center" height="40" width="120" ></a>
 
